==> haskell-transformers-compat-0.5.1.4-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-transformers-compat.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: transformers-compat
version: 0.5.1.4
id: transformers-compat-0.5.1.4-8ofY1OHzPhX5dvYk512o2v
key: transformers-compat-0.5.1.4-8ofY1OHzPhX5dvYk512o2v
license: BSD3
copyright: Copyright (C) 2012-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/transformers-compat/
synopsis: A small compatibility shim exposing the new types from transformers 0.3 and 0.4 to older Haskell platforms.
description:
    This package includes backported versions of types that were added
    to transformers in transformers 0.3, 0.4, and 0.5 for users who need strict
    transformers 0.2 or 0.3 compatibility to run on old versions of the
    platform, but also need those types.
    .
    Those users should be able to just depend on @transformers >= 0.2@
    and @transformers-compat >= 0.3@.
    .
    Note: missing methods are not supplied, but this at least permits the types to be used.
category: Compatibility
author: Edward A. Kmett
exposed: True
indefinite: False
exposed-modules:
    Control.Monad.Trans.Instances
hidden-modules: Paths_transformers_compat
abi: e48d0ae1a0338f5c9f46149b634d1da7
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/transformers-compat-0.5.1.4
library-dirs: /usr/lib/ghc-8.2.1/site-local/transformers-compat-0.5.1.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/transformers-compat-0.5.1.4
hs-libraries: HStransformers-compat-0.5.1.4-8ofY1OHzPhX5dvYk512o2v
depends:
    base-4.10.0.0 transformers-0.5.2.0 ghc-prim-0.5.1.0
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             transformers-0.5.2.0=9705988bf0172d3bbbcdcaf65e1d842a
             ghc-prim-0.5.1.0=557c7fce76ef13c2417583cc28848f14
haddock-interfaces: /usr/share/doc/haskell-transformers-compat/html/transformers-compat.haddock
haddock-html: /usr/share/doc/haskell-transformers-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-transformers-compat-0.5.1.4-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-transformers-compat.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: transformers-compat
version: 0.5.1.4
id: transformers-compat-0.5.1.4-EAh8Ccrgitz4vTZtbTPyCM
key: transformers-compat-0.5.1.4-EAh8Ccrgitz4vTZtbTPyCM
license: BSD3
copyright: Copyright (C) 2012-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/transformers-compat/
synopsis: A small compatibility shim exposing the new types from transformers 0.3 and 0.4 to older Haskell platforms.
description:
    This package includes backported versions of types that were added
    to transformers in transformers 0.3, 0.4, and 0.5 for users who need strict
    transformers 0.2 or 0.3 compatibility to run on old versions of the
    platform, but also need those types.
    .
    Those users should be able to just depend on @transformers >= 0.2@
    and @transformers-compat >= 0.3@.
    .
    Note: missing methods are not supplied, but this at least permits the types to be used.
category: Compatibility
author: Edward A. Kmett
exposed: True
indefinite: False
exposed-modules:
    Control.Monad.Trans.Instances
hidden-modules: Paths_transformers_compat
abi: 506de314acc216de1ce76634db1785eb
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/transformers-compat-0.5.1.4
library-dirs: /usr/lib/ghc-8.2.2/site-local/transformers-compat-0.5.1.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/transformers-compat-0.5.1.4
hs-libraries: HStransformers-compat-0.5.1.4-EAh8Ccrgitz4vTZtbTPyCM
depends:
    base-4.10.1.0 transformers-0.5.2.0 ghc-prim-0.5.1.1
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             ghc-prim-0.5.1.1=84323a6edd008b04bf217464a4ccaf16
haddock-interfaces: /usr/share/doc/haskell-transformers-compat/html/transformers-compat.haddock
haddock-html: /usr/share/doc/haskell-transformers-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
